@@ -12,7 +12,7 @@ BEGIN { $| = 1; print "1..15\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use lib '.';
 use lib './blib';
-use Modem;
+use Device::Modem;
 
 $loaded = 1;
 print "ok 1\n";
